==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/sl-SI/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Kategorije sredstev',
    'category_name'  					=> 'Ime kategorije',
    'checkin_email'                     => 'Pošlji e-pošto uporabniku ob sprejemu/izdaji.',
    'checkin_email_notification'        => 'Uporabnik bo poslan e-pošto ob sprejemu/izdaji.',
    'clone'                             => 'Kloniraj Karegorijo',
    'create'  							=> 'Ustvari kategorijo',
    'edit'                              => 'Uredi Kategorijo',
    'email_will_be_sent_due_to_global_eula' => 'An email will be sent to the user because the global EULA is being used.',
    'email_will_be_sent_due_to_category_eula' => 'An email will be sent to the user because a EULA is set for this category.',
    'eula_text'							=> 'Kategorija EULA',
    'eula_text_help'					=> 'To polje vam omogoča prilagajanje EULA za določene vrste sredstev. Če imate samo eno EULA za vsa vaša sredstva, lahko potrdite spodnje polje, da uporabite kot privzeto.',
    'name'                              => 'Ime kategorije',
    'require_acceptance'				=> 'Uporabniki morajo potrditi sprejem sredstev v tej kategoriji.',
    'required_acceptance'				=> 'Ta uporabnik bo prejel po e-pošti povezavo za potrditev sprejema tega elementa.',
    'required_eula'						=> 'Ta uporabnik bo po e-pošti prejel izvod EULA',
    'no_default_eula'					=> 'Ni privzete EULA. Dodajte eno v Nastavitvah.',
    'update'  							=> 'Posodobi kategorijo',
    'use_default_eula'					=> 'Uporabite <a href="#" data-toggle="modal" data-target="#eulaModal">privzeto EULA</a> namesto tega.',
    'use_default_eula_disabled'			=> '<del>Namesto tega uporabite privzeto EULA.</del> Ni privzete EULA. Dodajte jo v Nastavitvah.',
    'use_default_eula_column'			=> 'Uporabi privzeto EULA',

);

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/sl-SI/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Kategorije sredstev',
    'category_name'  					=> 'Ime kategorije',
    'checkin_email'                     => 'Pošlji e-pošto uporabniku ob sprejemu/izdaji.',
    'checkin_email_notification'        => 'Uporabnik bo poslan e-pošto ob sprejemu/izdaji.',
    'clone'                             => 'Kloniraj Karegorijo',
    'create'  							=> 'Ustvari kategorijo',
    'edit'                              => 'Uredi Kategorijo',
    'email_will_be_sent_due_to_global_eula' => 'E pošta bo uporabniku poslana ker je v uporabi globalna EULA.',
    'email_will_be_sent_due_to_category_eula' => 'E pošta bo bila poslana uporabniku, ker je za to kategorijo v uporabi EULA.',
    'eula_text'							=> 'Kategorija EULA',
    'eula_text_help'					=> 'To polje vam omogoča prilagajanje EULA za določene vrste sredstev. Če imate samo eno EULA za vsa vaša sredstva, lahko potrdite spodnje polje, da uporabite kot privzeto.',
    'name'                              => 'Ime kategorije',
    'require_acceptance'				=> 'Uporabniki morajo potrditi sprejem sredstev v tej kategoriji.',
    'required_acceptance'				=> 'Ta uporabnik bo prejel po e-pošti povezavo za potrditev sprejema tega elementa.',
    'required_eula'						=> 'Ta uporabnik bo po e-pošti prejel izvod EULA',
    'no_default_eula'					=> 'Ni privzete EULA. Dodajte eno v Nastavitvah.',
    'update'  							=> 'Posodobi kategorijo',
    'use_default_eula'					=> 'Uporabite <a href="#" data-toggle="modal" data-target="#eulaModal">privzeto EULA</a> namesto tega.',
    'use_default_eula_disabled'			=> '<del>Namesto tega uporabite privzeto EULA.</del> Ni privzete EULA. Dodajte jo v Nastavitvah.',
    'use_default_eula_column'			=> 'Uporabi privzeto EULA',

);
